===============================
 Gnocchi - Metric as a Service
===============================

.. image:: doc/source/gnocchi-logo.jpg

Gnocchi is a multi-tenant timeseries, metrics and resources database. It
provides an `HTTP REST`_ interface to create and manipulate the data. It is
designed to store metrics at a very large scale while providing access to
metrics and resources information to operators and users.

Gnocchi is part of the `OpenStack` project. While Gnocchi has support for
OpenStack, it is fully able to work stand-alone.

You can read the full documentation online at http://gnocchi.xyz.

.. _`HTTP REST`: https://en.wikipedia.org/wiki/Representational_state_transfer
